@@ -1,7 +1,13 @@
 from enum import Enum
 from typing import List
 import asyncio
-    
+
+class Progress:
+    val = 0
+    def setVal(self, val):
+        self.val = val
+    pass
+
 class async_state_transition:
     def __init__(self, *, taskMapName : str, stateToChangeName : str, validEntryStates : List[Enum], transitionState : Enum, signal, arg):
         """
@@ -54,11 +60,13 @@ class async_state_transition:
             obj.__setattr__(self.__stateToChangeName, self.__transitionState)
             
             # Add a member to the object called self.__stateToChangeName progress
-            obj.__setattr__(self.__stateToChangeName + "Progress", 0)
+            obj.__setattr__(self.__stateToChangeName + "Progress", Progress())
+
+            feedback = obj.__getattribute__(self.__stateToChangeName + "Progress")
 
             # Schedule a job to be executed when signal has finished executing
             async def __job():
-                await self.__signal(self.__signalArg)
+                await self.__signal(feedback, self.__signalArg) # wait for signal
                 await f(*args) # transition to the final state
                 taskMap.pop(self.__stateToChangeName) # remove task from the pending task map
 
@@ -71,7 +79,7 @@ class async_state_transition:
  
 async def timeDelay(feedback, time):
     for i in range(0,100):
-        feedback(i)
+        feedback.setVal(i)
         await asyncio.sleep(time/100)
 
 class state_transition_canceler:
